%global _hardened_build 1

# use SysV init for EPEL 5/6
%if 0%{?rhel}%{?fedora} < 7
%define use_sysv 1
%endif

Name:           up-imapproxy
Summary:        University of Pittsburgh IMAP Proxy
Version:        1.2.8
Release:        0.3.20130726svn14389%{?dist}
License:        GPLv2+
Group:          System Environment/Daemons
URL:            http://www.imapproxy.org
# The source for this package was pulled from upstream's vcs.  Use the
# following commands to generate the tarball:
#  svn export -r 14389 https://svn.code.sf.net/p/squirrelmail/code/trunk/imap_proxy squirrelmail-imap_proxy-1.2.8
#  tar cJvf squirrelmail-imap_proxy-20130726svn14389.tar.gz squirrelmail-imap_proxy-1.2.8
Source0:        squirrelmail-imap_proxy-20130726svn14389.tar.gz
Source1:        imapproxy.service
Source2:        imapproxy.init
# handle aarch64 per RH BZ 926684
Patch0:         http://ausil.fedorapeople.org/aarch64/up-imapproxy/up-imapproxy-aarch64.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
%if 0%{?rhel} == 5
BuildRequires:  tcp_wrappers
%else
BuildRequires:  tcp_wrappers-devel
%endif
BuildRequires:  openssl-devel ncurses-devel
%if 0%{?use_sysv}
Requires(post): chkconfig
Requires(preun): chkconfig
Requires(preun): initscripts
Requires(postun): initscripts
%else
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd
BuildRequires: systemd
%endif

%description
imapproxy was written to compensate for webmail clients that are
unable to maintain persistent connections to an IMAP server. Most
webmail clients need to log in to an IMAP server for nearly every
single transaction. This behaviour can cause tragic performance
problems on the IMAP server. imapproxy tries to deal with this problem
by leaving server connections open for a short time after a webmail
client logs out. When the webmail client connects again, imapproxy
will determine if there's a cached connection available and reuse it
if possible.

%prep
%setup -q -n squirrelmail-imap_proxy-%{version}
# handle aarch64
%patch0 -p1

%build
%configure
[ -d bin ] || mkdir bin
make %{?_smp_mflags}

%install
rm -rf $RPM_BUILD_ROOT
# The install-* Makefile targets don't support DESTDIR syntax, so work around.
install -D -m 0644 -p scripts/imapproxy.conf \
    $RPM_BUILD_ROOT%{_sysconfdir}/imapproxy.conf
%if 0%{?use_sysv}
install -D -m 0755 -p %{SOURCE2} \
    $RPM_BUILD_ROOT%{_sysconfdir}/rc.d/init.d/imapproxy
%else
install -D -m 0755 -p %{SOURCE1} $RPM_BUILD_ROOT%{_unitdir}/imapproxy.service
%endif
install -d -m 0755 $RPM_BUILD_ROOT%{_sbindir}
install -m 0755 bin/* $RPM_BUILD_ROOT%{_sbindir}
install -d -m 0755 $RPM_BUILD_ROOT%{_localstatedir}/run
touch $RPM_BUILD_ROOT%{_localstatedir}/run/pimpstats

# Fix doc permissions
chmod 644 README* COPYING copyright ChangeLog

# Fix debuginfo package file permission
chmod 644 include/imapproxy.h src/main.c

%clean
rm -rf $RPM_BUILD_ROOT

%post
%if 0%{?use_sysv}
/sbin/chkconfig --add imapproxy > /dev/null 2>&1
%else
%systemd_post imapproxy.service
%endif

%preun
%if 0%{?use_sysv}
if [ "$1" -eq 0 ]; then
    /sbin/service imapproxy stop > /dev/null 2>&1
    /sbin/chkconfig --del imapproxy
fi
%else
%systemd_preun imapproxy.service
%endif

%postun
%if 0%{?use_sysv}
if [ "$1" -ge 1 ]; then
    /sbin/service imapproxy condrestart > /dev/null 2>&1 || :
fi
%else
%systemd_postun_with_restart imapproxy.service 
%endif

%files
%defattr(-,root,root,-)
%doc COPYING ChangeLog README README.ssl
%doc copyright
%config(noreplace) %{_sysconfdir}/imapproxy.conf
%ghost %{_localstatedir}/run/pimpstats
%if 0%{?use_sysv}
%{_sysconfdir}/rc.d/init.d/*
%else
%{_unitdir}/imapproxy.service
%endif
%{_sbindir}/*

%changelog

* Tue Oct 1 2013 Manuel Wolfshant <wolfy@fedoraproject.org> 1.2.8-0.3.20130726svn14389
- Install correct initscript in SysV distros ( thanks Chris Adams )

* Sun Sep 22 2013 Manuel Wolfshant <wolfy@fedoraproject.org> 1.2.8-0.2.20130726svn14389
- Conditionalize BuildRequires for tcp wrappers for EL5/rest of the builds

* Tue Sep 17 2013 Chris Adams <linux@cmadams.net> - 1.2.8-0.1.20130726svn14389
- Update to upstream Subversion snapshot to get bug fixes
- Apply autoconf patch to handle aarch64
- Update spec to latest startup script handling, also conditionalize
  RHEL SysV init handle for EPEL to make it easier to handle both

* Thu Oct 23 2008 Manuel Wolfshant <wolfy@fedoraproject.org> 1.2.7-0.1.rc1
- updated to 1.2.7rc1 - security updates, buffer overflow etc.

* Thu Aug 28 2008 Rakesh Pandit <rakesh@fedoraproject.org> 1.2.6-2
- fixed initscript to follow guidelines

* Mon Jan 28 2008 Tim Jackson <rpm@timj.co.uk> - 1.2.6-1
- Update to 1.2.6
- Remove openssl patch (no longer required)
- Remove README.debian: we are not Debian
- Remove README.known_issues: they are all compilation/building issues
- Tidy init script

* Sun Jan 06 2008 Tim Jackson <rpm@timj.co.uk> - 1.2.5-1
- Update to 1.2.5
- Update License tag to "GPLv2+"
- Fix permissions on documentation
- Fix init script lockfile location

* Thu Sep 14 2006 Jeff Carlson <jeff@ultimateevil.org> - 1.2.4-7
- Force rebuild for FC-6.

* Thu Apr 27 2006 Jeff Carlson <jeff@ultimateevil.org> - 1.2.4-6
- Patch to fix changes in OpenSSL.
- Thanks to Paul W. Frields for providing the patch.

* Mon Dec 26 2005 Jeff Carlson <jeff@ultimateevil.org> - 1.2.4-5
- Rebuild against new OpenSSL in devel (fc5 only).

* Tue Oct 11 2005 Ville Skyttä <ville.skytta at iki.fi> - 1.2.4-4
- Fix for CAN-2005-2661 (#170220, from Debian).

* Fri Sep  9 2005 Jeff Carlson <jeff@ultimateevil.org> - 1.2.4-3
- Same as -2.

* Fri Sep  9 2005 Jeff Carlson <jeff@ultimateevil.org> - 1.2.4-2
- No-op release bump to get a new buildsys tag.

* Fri Sep  9 2005 Jeff Carlson <jeff@ultimateevil.org> - 1.2.4-1
- Bump to current upstream release.
- Upstream includes a new doc (copyright), included.

* Fri Sep  9 2005 Jeff Carlson <jeff@ultimateevil.org> - 1.2.3-6
- Another change to the init script.

* Sat Sep  3 2005 Jeff Carlson <jeff@ultimateevil.org> - 1.2.3-5
- Preserve certain timestamps.

* Thu Sep  1 2005 Jeff Carlson <jeff@ultimateevil.org> - 1.2.3-4
- Fix rpmlint complaints.
- Paul also provided a replacement init script.
- Fixed some redundant BuildReqs.
- Tuned Requires, install, and files.
- Many thanks to Paul Howarth.

* Wed Aug 31 2005 Jeff Carlson <jeff@ultimateevil.org> - 1.2.3-3
- Added BuildRequires.

* Fri Aug 12 2005 Jeff Carlson <jeff@ultimateevil.org> - 1.2.3-2
- Multiple fixups recommended by spot.

* Mon Jul 18 2005 Jeff Carlson <jeff@ultimateevil.org> - 1.2.3-1
- Initial build.
